package Weed::Component::Core;
use strict;
use warnings;

our $VERSION = '0.0011';

use Weed;

our $DESCRIPTION = '
X3DComponentCore : X3DComponent {
  SFNode [in,out] metadata NULL [X3DMetadataObject]
}
';

1;
__END__
